@@ -1,5 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
+ * Copyright © 2015 Alessandro Bono
  * Copyright © 2014, 2015 Pranav Kant
  * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
  *
@@ -48,8 +49,11 @@
 #include "photos-resources.h"
 #include "photos-search-context.h"
 #include "photos-search-controller.h"
+#include "photos-search-match.h"
+#include "photos-search-type.h"
 #include "photos-search-provider.h"
 #include "photos-single-item-job.h"
+#include "photos-source.h"
 #include "photos-source-manager.h"
 #include "photos-tracker-extract-priority.h"
 #include "photos-utils.h"
@@ -68,6 +72,9 @@ struct _PhotosApplicationPrivate
   GSimpleAction *print_action;
   GSimpleAction *properties_action;
   GSimpleAction *search_action;
+  GSimpleAction *search_match_action;
+  GSimpleAction *search_source_action;
+  GSimpleAction *search_type_action;
   GSimpleAction *sel_all_action;
   GSimpleAction *sel_none_action;
   GSimpleAction *set_bg_action;
@@ -297,21 +304,6 @@ photos_application_get_state (PhotosSearchContext *context)
 }
 
 
-static void
-photos_application_init_app_menu (PhotosApplication *self)
-{
-  GMenu *menu;
-  GtkBuilder *builder;
-
-  builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, "/org/gnome/photos/app-menu.ui", NULL);
-
-  menu = G_MENU (gtk_builder_get_object (builder, "app-menu"));
-  gtk_application_set_app_menu (GTK_APPLICATION (self), G_MENU_MODEL (menu));
-  g_object_unref (builder);
-}
-
-
 static void
 photos_application_launch_search (PhotosApplication *self, const gchar* const *terms, guint timestamp)
 {
@@ -594,7 +586,7 @@ photos_application_theme_changed (GtkSettings *settings)
           GFile *file;
 
           provider = gtk_css_provider_new ();
-          file = g_file_new_for_uri ("resource:///org/gnome/photos/Adwaita.css");
+          file = g_file_new_for_uri ("resource:///org/gnome/Photos/Adwaita.css");
           gtk_css_provider_load_from_file (provider, file, NULL);
           g_object_unref (file);
         }
@@ -685,6 +677,14 @@ photos_application_window_mode_changed (PhotosApplication *self, PhotosWindowMod
   PhotosApplicationPrivate *priv = self->priv;
   gboolean enable;
 
+  enable = (mode == PHOTOS_WINDOW_MODE_COLLECTIONS
+            || mode == PHOTOS_WINDOW_MODE_FAVORITES
+            || mode == PHOTOS_WINDOW_MODE_OVERVIEW
+            || mode == PHOTOS_WINDOW_MODE_SEARCH);
+  g_simple_action_set_enabled (priv->search_match_action, enable);
+  g_simple_action_set_enabled (priv->search_source_action, enable);
+  g_simple_action_set_enabled (priv->search_type_action, enable);
+
   enable = (mode == PHOTOS_WINDOW_MODE_OVERVIEW
             || mode == PHOTOS_WINDOW_MODE_COLLECTIONS
             || mode == PHOTOS_WINDOW_MODE_FAVORITES);
@@ -777,7 +777,6 @@ photos_application_shutdown (GApplication *application)
 {
   PhotosApplication *self = PHOTOS_APPLICATION (application);
 
-  gegl_exit ();
   tracker_extract_priority_call_clear_rdf_types (self->priv->extract_priority,
                                                  NULL,
                                                  photos_application_tracker_clear_rdf_types,
@@ -800,6 +799,7 @@ photos_application_startup (GApplication *application)
   GrlRegistry *registry;
   GtkSettings *settings;
   GVariant *state;
+  GVariantType *parameter_type;
   const gchar *fullscreen_accels[2] = {"F11", NULL};
   const gchar *gear_menu_accels[2] = {"F10", NULL};
   const gchar *print_current_accels[2] = {"<Primary>p", NULL};
@@ -844,19 +844,12 @@ photos_application_startup (GApplication *application)
           GomMiner *miner;
           const gchar *extension_name;
 
-          error = NULL;
           miner = gom_miner_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
                                                     G_DBUS_PROXY_FLAGS_NONE,
                                                     base_item_class->miner_name,
                                                     base_item_class->miner_object_path,
                                                     NULL,
-                                                    &error);
-          if (error != NULL)
-            {
-              g_warning ("Unable to create GomMiner proxy for %s: %s", base_item_class->miner_name, error->message);
-              g_error_free (error);
-              continue;
-            }
+                                                    NULL);
 
           extension_name = g_io_extension_get_name (extension);
           g_object_set_data_full (G_OBJECT (miner), "provider-type", g_strdup (extension_name), g_free);
@@ -931,6 +924,24 @@ photos_application_startup (GApplication *application)
   g_signal_connect (priv->search_action, "activate", G_CALLBACK (photos_application_action_toggle), self);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (priv->search_action));
 
+  parameter_type = g_variant_type_new ("s");
+  state = g_variant_new ("s", PHOTOS_SEARCH_MATCH_STOCK_ALL);
+  priv->search_match_action = g_simple_action_new_stateful ("search-match", parameter_type, state);
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (priv->search_match_action));
+  g_variant_type_free (parameter_type);
+
+  parameter_type = g_variant_type_new ("s");
+  state = g_variant_new ("s", PHOTOS_SOURCE_STOCK_ALL);
+  priv->search_source_action = g_simple_action_new_stateful ("search-source", parameter_type, state);
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (priv->search_source_action));
+  g_variant_type_free (parameter_type);
+
+  parameter_type = g_variant_type_new ("s");
+  state = g_variant_new ("s", PHOTOS_SEARCH_TYPE_STOCK_ALL);
+  priv->search_type_action = g_simple_action_new_stateful ("search-type", parameter_type, state);
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (priv->search_type_action));
+  g_variant_type_free (parameter_type);
+
   priv->sel_all_action = g_simple_action_new ("select-all", NULL);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (priv->sel_all_action));
 
@@ -958,8 +969,6 @@ photos_application_startup (GApplication *application)
                             G_CALLBACK (photos_application_window_mode_changed),
                             self);
 
-  photos_application_init_app_menu (self);
-
   action = g_simple_action_new ("help", NULL);
   g_signal_connect_swapped (action, "activate", G_CALLBACK (photos_application_help), self);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (action));
@@ -1025,6 +1034,9 @@ photos_application_dispose (GObject *object)
   g_clear_object (&priv->print_action);
   g_clear_object (&priv->properties_action);
   g_clear_object (&priv->search_action);
+  g_clear_object (&priv->search_match_action);
+  g_clear_object (&priv->search_source_action);
+  g_clear_object (&priv->search_type_action);
   g_clear_object (&priv->sel_all_action);
   g_clear_object (&priv->sel_none_action);
   g_clear_object (&priv->set_bg_action);
