@@ -283,7 +283,7 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
 
       slice = photos_utils_get_thumbnail_frame_border ();
       thumbnailed_pixbuf = gd_embed_image_in_frame (emblemed_pixbuf,
-                                                    "resource:///org/gnome/photos/thumbnail-frame.png",
+                                                    "resource:///org/gnome/Photos/thumbnail-frame.png",
                                                     slice,
                                                     slice);
       gtk_border_free (slice);
@@ -404,14 +404,7 @@ photos_base_item_create_thumbnail_finish (PhotosBaseItem *self, GAsyncResult *re
 static void
 photos_base_item_default_set_favorite (PhotosBaseItem *self, gboolean favorite)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
-
-  if (favorite == priv->favorite)
-    return;
-
-  priv->favorite = favorite;
-  photos_base_item_check_effects_and_update_info (self);
-  photos_utils_set_favorite (priv->id, favorite);
+  photos_utils_set_favorite (self->priv->id, favorite);
 }
 
 
