@@ -45,9 +45,7 @@
 #include "photos-search-type-manager.h"
 #include "photos-source.h"
 #include "photos-source-manager.h"
-#include "photos-tracker-controller.h"
 #include "photos-tracker-overview-controller.h"
-#include "photos-utils.h"
 #include "photos-view-container.h"
 #include "photos-view-model.h"
 
@@ -65,7 +63,6 @@ struct _PhotosEmbedSearchState
 struct _PhotosEmbedPrivate
 {
   GAction *search_action;
-  GIOExtensionPoint *extension_point;
   GtkWidget *collections;
   GtkWidget *favorites;
   GtkWidget *no_results;
@@ -276,6 +273,8 @@ photos_embed_load_started (PhotosEmbed *self, PhotosBaseItem *item, GCancellable
     }
 
   photos_mode_controller_set_window_mode (priv->mode_cntrlr, PHOTOS_WINDOW_MODE_PREVIEW);
+  photos_mode_controller_set_can_fullscreen (priv->mode_cntrlr, TRUE);
+
   photos_main_toolbar_set_cancellable (PHOTOS_MAIN_TOOLBAR (priv->toolbar), cancellable);
 
   photos_embed_clear_load_timer (self);
@@ -317,32 +316,6 @@ photos_embed_save_search (PhotosEmbed *self)
 }
 
 
-static void
-photos_embed_tracker_controllers_set_frozen (PhotosEmbed *self, gboolean frozen)
-{
-  GList *extensions;
-  GList *l;
-
-  extensions = g_io_extension_point_get_extensions (self->priv->extension_point);
-  for (l = extensions; l != NULL; l = l->next)
-    {
-      GIOExtension *extension = (GIOExtension *) l->data;
-      GType type;
-      PhotosTrackerController *trk_cntrlr;
-
-      type = g_io_extension_get_type (extension);
-
-      /* Strictly speaking, we need to set the "mode" too, but that
-       * is a bit inconvenient, so we operate under the assumption
-       * that the objects have already been constructed.
-       */
-      trk_cntrlr = PHOTOS_TRACKER_CONTROLLER (g_object_new (type, NULL));
-      photos_tracker_controller_set_frozen (trk_cntrlr, frozen);
-      g_object_unref (trk_cntrlr);
-    }
-}
-
-
 static void
 photos_embed_active_changed (PhotosBaseManager *manager, GObject *object, gpointer user_data)
 {
@@ -354,22 +327,12 @@ photos_embed_active_changed (PhotosBaseManager *manager, GObject *object, gpoint
   GVariant *state;
   gboolean show_search;
 
-  active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (priv->item_mngr));
-  active_item = photos_base_manager_get_active_object (priv->item_mngr);
-
-  /* We want to freeze before saving the search state and to thaw
-   * after restoring it. We could thaw it earlier too, but that would
-   * lead to a bunch of needless queries from the TrackerControllers.
-   *
-   * Note that we don't want to freeze when showing a collection.
-   */
-  if (active_item != (GObject *) active_collection) /* active_item != NULL */
-    photos_embed_tracker_controllers_set_frozen (self, TRUE);
-
   /* Hide the search bar when we are moving from the search to the
    * preview or collection viewin. Restore it when we are back.
    */
 
+  active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (priv->item_mngr));
+  active_item = photos_base_manager_get_active_object (priv->item_mngr);
   mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
   show_search = (mode == PHOTOS_WINDOW_MODE_PREVIEW && active_item == NULL && active_collection == NULL)
                 || (mode == PHOTOS_WINDOW_MODE_SEARCH && active_item == NULL);
@@ -381,10 +344,6 @@ photos_embed_active_changed (PhotosBaseManager *manager, GObject *object, gpoint
 
   state = g_variant_new ("b", show_search);
   g_action_change_state (priv->search_action, state);
-
-  /* See above. */
-  if (active_item == (GObject *) active_collection) /* active_item == NULL */
-    photos_embed_tracker_controllers_set_frozen (self, FALSE);
 }
 
 
@@ -556,29 +515,45 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
   PhotosEmbedPrivate *priv = self->priv;
+  GtkListStore *model;
+  GtkWidget *view_container;
 
   photos_main_toolbar_reset_toolbar_mode (PHOTOS_MAIN_TOOLBAR (priv->toolbar));
 
-  if (mode == PHOTOS_WINDOW_MODE_PREVIEW)
-    photos_embed_prepare_for_preview (self);
-  else
+  switch (mode)
     {
-      GtkListStore *model;
-      GtkWidget *view_container;
+    case PHOTOS_WINDOW_MODE_COLLECTIONS:
+      photos_embed_prepare_for_collections (self);
+      goto set_toolbar_model;
 
-      if (mode == PHOTOS_WINDOW_MODE_COLLECTIONS)
-        photos_embed_prepare_for_collections (self);
-      else if (mode == PHOTOS_WINDOW_MODE_FAVORITES)
-        photos_embed_prepare_for_favorites (self);
-      else if (mode == PHOTOS_WINDOW_MODE_OVERVIEW)
-        photos_embed_prepare_for_overview (self);
-      else if (mode == PHOTOS_WINDOW_MODE_SEARCH)
-        photos_embed_prepare_for_search (self);
+    case PHOTOS_WINDOW_MODE_FAVORITES:
+      photos_embed_prepare_for_favorites (self);
+      goto set_toolbar_model;
 
-      view_container = photos_embed_get_view_container_from_mode (self, mode);
-      model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-      photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (priv->toolbar), PHOTOS_VIEW_MODEL (model));
+    case PHOTOS_WINDOW_MODE_OVERVIEW:
+      photos_embed_prepare_for_overview (self);
+      goto set_toolbar_model;
+
+    case PHOTOS_WINDOW_MODE_PREVIEW:
+      photos_embed_prepare_for_preview (self);
+      break;
+
+    case PHOTOS_WINDOW_MODE_SEARCH:
+      photos_embed_prepare_for_search (self);
+      goto set_toolbar_model;
+
+    case PHOTOS_WINDOW_MODE_NONE:
+    default:
+      g_assert_not_reached ();
+      break;
     }
+
+  return;
+
+ set_toolbar_model:
+  view_container = photos_embed_get_view_container_from_mode (self, mode);
+  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
+  photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (priv->toolbar), PHOTOS_VIEW_MODEL (model));
 }
 
 
@@ -636,8 +611,6 @@ photos_embed_init (PhotosEmbed *self)
   gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
   gtk_widget_show (GTK_WIDGET (self));
 
-  priv->extension_point = g_io_extension_point_lookup (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME);
-
   priv->selection_toolbar = photos_selection_toolbar_new ();
   gtk_box_pack_end (GTK_BOX (self), priv->selection_toolbar, FALSE, FALSE, 0);
 
@@ -665,28 +638,28 @@ photos_embed_init (PhotosEmbed *self)
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->overview));
   gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->overview));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
+  g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
   priv->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->collections));
   gtk_stack_add_titled (GTK_STACK (priv->stack), priv->collections, "collections", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->collections));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
+  g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
   priv->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->favorites));
   gtk_stack_add_titled (GTK_STACK (priv->stack), priv->favorites, "favorites", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->favorites));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
+  g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
   priv->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH, _("Search"));
   gtk_stack_add_named (GTK_STACK (priv->stack), priv->search, "search");
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->search));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
+  g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
   priv->preview = photos_preview_view_new (GTK_OVERLAY (priv->stack_overlay));
   gtk_stack_add_named (GTK_STACK (priv->stack), priv->preview, "preview");
@@ -697,9 +670,11 @@ photos_embed_init (PhotosEmbed *self)
   /* TODO: SearchBar.Dropdown, …
    */
 
-  g_signal_connect_object (priv->stack, "notify::visible-child",
+  g_signal_connect_object (priv->stack,
+                           "notify::visible-child",
                            G_CALLBACK (photos_embed_notify_visible_child),
-                           self, G_CONNECT_SWAPPED);
+                           self,
+                           G_CONNECT_SWAPPED);
 
   priv->mode_cntrlr = photos_mode_controller_dup_singleton ();
   g_signal_connect_object (priv->mode_cntrlr,
