@@ -227,8 +227,23 @@ photos_preview_view_create_view (PhotosPreviewView *self)
 static void
 photos_preview_view_window_mode_changed (PhotosPreviewView *self, PhotosWindowMode mode, PhotosWindowMode old_mode)
 {
-  if (mode != PHOTOS_WINDOW_MODE_PREVIEW)
-    photos_preview_nav_buttons_hide (self->priv->nav_buttons);
+  switch (mode)
+    {
+    case PHOTOS_WINDOW_MODE_COLLECTIONS:
+    case PHOTOS_WINDOW_MODE_FAVORITES:
+    case PHOTOS_WINDOW_MODE_OVERVIEW:
+    case PHOTOS_WINDOW_MODE_SEARCH:
+      photos_preview_nav_buttons_hide (self->priv->nav_buttons);
+      break;
+
+    case PHOTOS_WINDOW_MODE_PREVIEW:
+      break;
+
+    case PHOTOS_WINDOW_MODE_NONE:
+    default:
+      g_assert_not_reached ();
+      break;
+    }
 }
 
 
